@@ -1,13 +1,9 @@
 import logging
 import unittest
-
-import six
-if six.PY3:
-    from unittest import mock
-else:
-    import mock
+from unittest import mock
 
 from engineio.async_drivers import eventlet as async_eventlet
+import pytest
 
 
 class TestAsyncEventlet(unittest.TestCase):
@@ -18,13 +14,16 @@ class TestAsyncEventlet(unittest.TestCase):
         wsgi = async_eventlet.WebSocketWSGI(None)
         environ = {'foo': 'bar'}
         start_response = 'bar'
-        self.assertRaises(RuntimeError, wsgi, environ, start_response)
+        with pytest.raises(RuntimeError):
+            wsgi(environ, start_response)
 
-    @mock.patch('engineio.async_drivers.eventlet._WebSocketWSGI.__call__',
-                return_value='data')
+    @mock.patch(
+        'engineio.async_drivers.eventlet._WebSocketWSGI.__call__',
+        return_value='data',
+    )
     def test_wsgi_call(self, _WebSocketWSGI):
         _WebSocketWSGI.__call__ = lambda e, s: 'data'
         environ = {'eventlet.input': mock.MagicMock()}
         start_response = 'bar'
         wsgi = async_eventlet.WebSocketWSGI(None)
-        self.assertEqual(wsgi(environ, start_response), 'data')
+        assert wsgi(environ, start_response) == 'data'
