@@ -1,11 +1,9 @@
+import io
 import time
 import unittest
+from unittest import mock
 
-import six
-if six.PY3:
-    from unittest import mock
-else:
-    import mock
+import pytest
 
 from engineio import exceptions
 from engineio import packet
@@ -29,9 +27,12 @@ class TestSocket(unittest.TestCase):
         except ImportError:
             import Queue as queue
         import threading
-        mock_server._async = {'threading': threading.Thread,
-                              'queue': queue.Queue,
-                              'websocket': None}
+
+        mock_server._async = {
+            'threading': threading.Thread,
+            'queue': queue.Queue,
+            'websocket': None,
+        }
 
         def bg_task(target, *args, **kwargs):
             th = threading.Thread(target=target, args=args, kwargs=kwargs)
@@ -54,19 +55,20 @@ class TestSocket(unittest.TestCase):
     def test_create(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
-        self.assertEqual(s.server, mock_server)
-        self.assertEqual(s.sid, 'sid')
-        self.assertFalse(s.upgraded)
-        self.assertFalse(s.closed)
-        self.assertTrue(hasattr(s.queue, 'get'))
-        self.assertTrue(hasattr(s.queue, 'put'))
-        self.assertTrue(hasattr(s.queue, 'task_done'))
-        self.assertTrue(hasattr(s.queue, 'join'))
+        assert s.server == mock_server
+        assert s.sid == 'sid'
+        assert not s.upgraded
+        assert not s.closed
+        assert hasattr(s.queue, 'get')
+        assert hasattr(s.queue, 'put')
+        assert hasattr(s.queue, 'task_done')
+        assert hasattr(s.queue, 'join')
 
     def test_empty_poll(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
-        self.assertRaises(exceptions.QueueEmpty, s.poll)
+        with pytest.raises(exceptions.QueueEmpty):
+            s.poll()
 
     def test_poll(self):
         mock_server = self._get_mock_server()
@@ -75,38 +77,73 @@ class TestSocket(unittest.TestCase):
         pkt2 = packet.Packet(packet.MESSAGE, data='bye')
         s.send(pkt1)
         s.send(pkt2)
-        self.assertEqual(s.poll(), [pkt1, pkt2])
+        assert s.poll() == [pkt1, pkt2]
 
-    def test_ping_pong(self):
+    def test_poll_none(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
-        s.receive(packet.Packet(packet.PING, data='abc'))
-        r = s.poll()
-        self.assertEqual(len(r), 1)
-        self.assertTrue(r[0].encode(), b'3abc')
+        s.queue.put(None)
+        assert s.poll() == []
+
+    def test_poll_none_after_packet(self):
+        mock_server = self._get_mock_server()
+        s = socket.Socket(mock_server, 'sid')
+        pkt = packet.Packet(packet.MESSAGE, data='hello')
+        s.send(pkt)
+        s.queue.put(None)
+        assert s.poll() == [pkt]
+        assert s.poll() == []
+
+    def test_schedule_ping(self):
+        mock_server = self._get_mock_server()
+        mock_server.ping_interval = 0.01
+        s = socket.Socket(mock_server, 'sid')
+        s.send = mock.MagicMock()
+        s.schedule_ping()
+        time.sleep(0.05)
+        assert s.last_ping is not None
+        assert s.send.call_args_list[0][0][0].encode() == '2'
+
+    def test_schedule_ping_closed_socket(self):
+        mock_server = self._get_mock_server()
+        mock_server.ping_interval = 0.01
+        s = socket.Socket(mock_server, 'sid')
+        s.send = mock.MagicMock()
+        s.closed = True
+        s.schedule_ping()
+        time.sleep(0.05)
+        assert s.last_ping is None
+        s.send.assert_not_called()
+
+    def test_pong(self):
+        mock_server = self._get_mock_server()
+        s = socket.Socket(mock_server, 'sid')
+        s.schedule_ping = mock.MagicMock()
+        s.receive(packet.Packet(packet.PONG))
+        s.schedule_ping.assert_called_once_with()
 
     def test_message_async_handler(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.receive(packet.Packet(packet.MESSAGE, data='foo'))
-        mock_server._trigger_event.assert_called_once_with('message', 'sid',
-                                                           'foo',
-                                                           run_async=True)
+        mock_server._trigger_event.assert_called_once_with(
+            'message', 'sid', 'foo', run_async=True
+        )
 
     def test_message_sync_handler(self):
         mock_server = self._get_mock_server()
         mock_server.async_handlers = False
         s = socket.Socket(mock_server, 'sid')
         s.receive(packet.Packet(packet.MESSAGE, data='foo'))
-        mock_server._trigger_event.assert_called_once_with('message', 'sid',
-                                                           'foo',
-                                                           run_async=False)
+        mock_server._trigger_event.assert_called_once_with(
+            'message', 'sid', 'foo', run_async=False
+        )
 
     def test_invalid_packet(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
-        self.assertRaises(exceptions.UnknownPacketError, s.receive,
-                          packet.Packet(packet.OPEN))
+        with pytest.raises(exceptions.UnknownPacketError):
+            s.receive(packet.Packet(packet.OPEN))
 
     def test_timeout(self):
         mock_server = self._get_mock_server()
@@ -128,49 +165,60 @@ class TestSocket(unittest.TestCase):
         environ = {'REQUEST_METHOD': 'GET', 'QUERY_STRING': 'sid=foo'}
         start_response = mock.MagicMock()
         packets = s.handle_get_request(environ, start_response)
-        self.assertEqual(packets, [pkt1, pkt2])
+        assert packets == [pkt1, pkt2]
 
     def test_polling_read_error(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'foo')
         environ = {'REQUEST_METHOD': 'GET', 'QUERY_STRING': 'sid=foo'}
         start_response = mock.MagicMock()
-        self.assertRaises(exceptions.QueueEmpty, s.handle_get_request, environ,
-                          start_response)
+        with pytest.raises(exceptions.QueueEmpty):
+            s.handle_get_request(environ, start_response)
 
     def test_polling_write(self):
         mock_server = self._get_mock_server()
         mock_server.max_http_buffer_size = 1000
         pkt1 = packet.Packet(packet.MESSAGE, data='hello')
         pkt2 = packet.Packet(packet.MESSAGE, data='bye')
-        p = payload.Payload(packets=[pkt1, pkt2]).encode()
+        p = payload.Payload(packets=[pkt1, pkt2]).encode().encode('utf-8')
         s = socket.Socket(mock_server, 'foo')
         s.receive = mock.MagicMock()
-        environ = {'REQUEST_METHOD': 'POST', 'QUERY_STRING': 'sid=foo',
-                   'CONTENT_LENGTH': len(p), 'wsgi.input': six.BytesIO(p)}
+        environ = {
+            'REQUEST_METHOD': 'POST',
+            'QUERY_STRING': 'sid=foo',
+            'CONTENT_LENGTH': len(p),
+            'wsgi.input': io.BytesIO(p),
+        }
         s.handle_post_request(environ)
-        self.assertEqual(s.receive.call_count, 2)
+        assert s.receive.call_count == 2
 
     def test_polling_write_too_large(self):
         mock_server = self._get_mock_server()
         pkt1 = packet.Packet(packet.MESSAGE, data='hello')
         pkt2 = packet.Packet(packet.MESSAGE, data='bye')
-        p = payload.Payload(packets=[pkt1, pkt2]).encode()
+        p = payload.Payload(packets=[pkt1, pkt2]).encode().encode('utf-8')
         mock_server.max_http_buffer_size = len(p) - 1
         s = socket.Socket(mock_server, 'foo')
         s.receive = mock.MagicMock()
-        environ = {'REQUEST_METHOD': 'POST', 'QUERY_STRING': 'sid=foo',
-                   'CONTENT_LENGTH': len(p), 'wsgi.input': six.BytesIO(p)}
-        self.assertRaises(exceptions.ContentTooLongError,
-                          s.handle_post_request, environ)
+        environ = {
+            'REQUEST_METHOD': 'POST',
+            'QUERY_STRING': 'sid=foo',
+            'CONTENT_LENGTH': len(p),
+            'wsgi.input': io.BytesIO(p),
+        }
+        with pytest.raises(exceptions.ContentTooLongError):
+            s.handle_post_request(environ)
 
     def test_upgrade_handshake(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'foo')
         s._upgrade_websocket = mock.MagicMock()
-        environ = {'REQUEST_METHOD': 'GET', 'QUERY_STRING': 'sid=foo',
-                   'HTTP_CONNECTION': 'Foo,Upgrade,Bar',
-                   'HTTP_UPGRADE': 'websocket'}
+        environ = {
+            'REQUEST_METHOD': 'GET',
+            'QUERY_STRING': 'sid=foo',
+            'HTTP_CONNECTION': 'Foo,Upgrade,Bar',
+            'HTTP_UPGRADE': 'websocket',
+        }
         start_response = mock.MagicMock()
         s.handle_get_request(environ, start_response)
         s._upgrade_websocket.assert_called_once_with(environ, start_response)
@@ -186,7 +234,8 @@ class TestSocket(unittest.TestCase):
         start_response = "bar"
         s._upgrade_websocket(environ, start_response)
         mock_server._async['websocket'].assert_called_once_with(
-            s._websocket_handler)
+            s._websocket_handler
+        )
         mock_ws.assert_called_once_with(environ, start_response)
 
     def test_upgrade_twice(self):
@@ -197,8 +246,8 @@ class TestSocket(unittest.TestCase):
         s.upgraded = True
         environ = "foo"
         start_response = "bar"
-        self.assertRaises(IOError, s._upgrade_websocket,
-                          environ, start_response)
+        with pytest.raises(IOError):
+            s._upgrade_websocket(environ, start_response)
 
     def test_upgrade_packet(self):
         mock_server = self._get_mock_server()
@@ -206,18 +255,17 @@ class TestSocket(unittest.TestCase):
         s.connected = True
         s.receive(packet.Packet(packet.UPGRADE))
         r = s.poll()
-        self.assertEqual(len(r), 1)
-        self.assertEqual(r[0].encode(), packet.Packet(packet.NOOP).encode())
+        assert len(r) == 1
+        assert r[0].encode() == packet.Packet(packet.NOOP).encode()
 
     def test_upgrade_no_probe(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.connected = True
         ws = mock.MagicMock()
-        ws.wait.return_value = packet.Packet(packet.NOOP).encode(
-            always_bytes=False)
+        ws.wait.return_value = packet.Packet(packet.NOOP).encode()
         s._websocket_handler(ws)
-        self.assertFalse(s.upgraded)
+        assert not s.upgraded
 
     def test_upgrade_no_upgrade_packet(self):
         mock_server = self._get_mock_server()
@@ -225,16 +273,17 @@ class TestSocket(unittest.TestCase):
         s.connected = True
         s.queue.join = mock.MagicMock(return_value=None)
         ws = mock.MagicMock()
-        probe = six.text_type('probe')
+        probe = 'probe'
         ws.wait.side_effect = [
-            packet.Packet(packet.PING, data=probe).encode(
-                always_bytes=False),
-            packet.Packet(packet.NOOP).encode(always_bytes=False)]
+            packet.Packet(packet.PING, data=probe).encode(),
+            packet.Packet(packet.NOOP).encode(),
+        ]
         s._websocket_handler(ws)
-        ws.send.assert_called_once_with(packet.Packet(
-            packet.PONG, data=probe).encode(always_bytes=False))
-        self.assertEqual(s.queue.get().packet_type, packet.NOOP)
-        self.assertFalse(s.upgraded)
+        ws.send.assert_called_once_with(
+            packet.Packet(packet.PONG, data=probe).encode()
+        )
+        assert s.queue.get().packet_type == packet.NOOP
+        assert not s.upgraded
 
     def test_close_packet(self):
         mock_server = self._get_mock_server()
@@ -248,7 +297,8 @@ class TestSocket(unittest.TestCase):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         pkt = packet.Packet(packet_type=99)
-        self.assertRaises(exceptions.UnknownPacketError, s.receive, pkt)
+        with pytest.raises(exceptions.UnknownPacketError):
+            s.receive(pkt)
 
     def test_upgrade_not_supported(self):
         mock_server = self._get_mock_server()
@@ -265,23 +315,30 @@ class TestSocket(unittest.TestCase):
         s = socket.Socket(mock_server, 'sid')
         s.connected = False
         s.queue.join = mock.MagicMock(return_value=None)
-        foo = six.text_type('foo')
-        bar = six.text_type('bar')
-        s.poll = mock.MagicMock(side_effect=[
-            [packet.Packet(packet.MESSAGE, data=bar)], exceptions.QueueEmpty])
+        foo = 'foo'
+        bar = 'bar'
+        s.poll = mock.MagicMock(
+            side_effect=[
+                [packet.Packet(packet.MESSAGE, data=bar)],
+                exceptions.QueueEmpty,
+            ]
+        )
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.MESSAGE, data=foo).encode(
-                always_bytes=False),
-            None]
+            packet.Packet(packet.MESSAGE, data=foo).encode(),
+            None,
+        ]
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertTrue(s.connected)
-        self.assertTrue(s.upgraded)
-        self.assertEqual(mock_server._trigger_event.call_count, 2)
-        mock_server._trigger_event.assert_has_calls([
-            mock.call('message', 'sid', 'foo', run_async=True),
-            mock.call('disconnect', 'sid', run_async=False)])
+        assert s.connected
+        assert s.upgraded
+        assert mock_server._trigger_event.call_count == 2
+        mock_server._trigger_event.assert_has_calls(
+            [
+                mock.call('message', 'sid', 'foo', run_async=True),
+                mock.call('disconnect', 'sid', run_async=False),
+            ]
+        )
         ws.send.assert_called_with('4bar')
 
     def test_websocket_upgrade_read_write(self):
@@ -289,26 +346,32 @@ class TestSocket(unittest.TestCase):
         s = socket.Socket(mock_server, 'sid')
         s.connected = True
         s.queue.join = mock.MagicMock(return_value=None)
-        foo = six.text_type('foo')
-        bar = six.text_type('bar')
-        probe = six.text_type('probe')
-        s.poll = mock.MagicMock(side_effect=[
-            [packet.Packet(packet.MESSAGE, data=bar)], exceptions.QueueEmpty])
+        foo = 'foo'
+        bar = 'bar'
+        probe = 'probe'
+        s.poll = mock.MagicMock(
+            side_effect=[
+                [packet.Packet(packet.MESSAGE, data=bar)],
+                exceptions.QueueEmpty,
+            ]
+        )
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.PING, data=probe).encode(
-                always_bytes=False),
-            packet.Packet(packet.UPGRADE).encode(always_bytes=False),
-            packet.Packet(packet.MESSAGE, data=foo).encode(
-                always_bytes=False),
-            None]
+            packet.Packet(packet.PING, data=probe).encode(),
+            packet.Packet(packet.UPGRADE).encode(),
+            packet.Packet(packet.MESSAGE, data=foo).encode(),
+            None,
+        ]
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertTrue(s.upgraded)
-        self.assertEqual(mock_server._trigger_event.call_count, 2)
-        mock_server._trigger_event.assert_has_calls([
-            mock.call('message', 'sid', 'foo', run_async=True),
-            mock.call('disconnect', 'sid', run_async=False)])
+        assert s.upgraded
+        assert mock_server._trigger_event.call_count == 2
+        mock_server._trigger_event.assert_has_calls(
+            [
+                mock.call('message', 'sid', 'foo', run_async=True),
+                mock.call('disconnect', 'sid', run_async=False),
+            ]
+        )
         ws.send.assert_called_with('4bar')
 
     def test_websocket_upgrade_with_payload(self):
@@ -316,100 +379,120 @@ class TestSocket(unittest.TestCase):
         s = socket.Socket(mock_server, 'sid')
         s.connected = True
         s.queue.join = mock.MagicMock(return_value=None)
-        probe = six.text_type('probe')
+        probe = 'probe'
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.PING, data=probe).encode(
-                always_bytes=False),
-            packet.Packet(packet.UPGRADE, data=b'2').encode(
-                always_bytes=False)]
+            packet.Packet(packet.PING, data=probe).encode(),
+            packet.Packet(packet.UPGRADE, data='2').encode(),
+        ]
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertTrue(s.upgraded)
+        assert s.upgraded
 
     def test_websocket_upgrade_with_backlog(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.connected = True
         s.queue.join = mock.MagicMock(return_value=None)
-        probe = six.text_type('probe')
-        foo = six.text_type('foo')
+        probe = 'probe'
+        foo = 'foo'
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.PING, data=probe).encode(
-                always_bytes=False),
-            packet.Packet(packet.UPGRADE, data=b'2').encode(
-                always_bytes=False)]
+            packet.Packet(packet.PING, data=probe).encode(),
+            packet.Packet(packet.UPGRADE, data='2').encode(),
+        ]
         s.upgrading = True
         s.send(packet.Packet(packet.MESSAGE, data=foo))
+        environ = {'REQUEST_METHOD': 'GET', 'QUERY_STRING': 'sid=sid'}
+        start_response = mock.MagicMock()
+        packets = s.handle_get_request(environ, start_response)
+        assert len(packets) == 1
+        assert packets[0].encode() == '6'
+        packets = s.poll()
+        assert len(packets) == 1
+        assert packets[0].encode() == '4foo'
+
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertTrue(s.upgraded)
-        self.assertFalse(s.upgrading)
-        self.assertEqual(s.packet_backlog, [])
-        ws.send.assert_called_with('4foo')
+        assert s.upgraded
+        assert not s.upgrading
+        packets = s.handle_get_request(environ, start_response)
+        assert len(packets) == 1
+        assert packets[0].encode() == '6'
 
     def test_websocket_read_write_wait_fail(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.connected = False
         s.queue.join = mock.MagicMock(return_value=None)
-        foo = six.text_type('foo')
-        bar = six.text_type('bar')
-        s.poll = mock.MagicMock(side_effect=[
-            [packet.Packet(packet.MESSAGE, data=bar)],
-            [packet.Packet(packet.MESSAGE, data=bar)], exceptions.QueueEmpty])
+        foo = 'foo'
+        bar = 'bar'
+        s.poll = mock.MagicMock(
+            side_effect=[
+                [packet.Packet(packet.MESSAGE, data=bar)],
+                [packet.Packet(packet.MESSAGE, data=bar)],
+                exceptions.QueueEmpty,
+            ]
+        )
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.MESSAGE, data=foo).encode(
-                always_bytes=False),
-            RuntimeError]
+            packet.Packet(packet.MESSAGE, data=foo).encode(),
+            RuntimeError,
+        ]
         ws.send.side_effect = [None, RuntimeError]
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertEqual(s.closed, True)
+        assert s.closed
 
     def test_websocket_ignore_invalid_packet(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.connected = False
         s.queue.join = mock.MagicMock(return_value=None)
-        foo = six.text_type('foo')
-        bar = six.text_type('bar')
-        s.poll = mock.MagicMock(side_effect=[
-            [packet.Packet(packet.MESSAGE, data=bar)], exceptions.QueueEmpty])
+        foo = 'foo'
+        bar = 'bar'
+        s.poll = mock.MagicMock(
+            side_effect=[
+                [packet.Packet(packet.MESSAGE, data=bar)],
+                exceptions.QueueEmpty,
+            ]
+        )
         ws = mock.MagicMock()
         ws.wait.side_effect = [
-            packet.Packet(packet.OPEN).encode(always_bytes=False),
-            packet.Packet(packet.MESSAGE, data=foo).encode(
-                always_bytes=False),
-            None]
+            packet.Packet(packet.OPEN).encode(),
+            packet.Packet(packet.MESSAGE, data=foo).encode(),
+            None,
+        ]
         s._websocket_handler(ws)
         self._join_bg_tasks()
-        self.assertTrue(s.connected)
-        self.assertEqual(mock_server._trigger_event.call_count, 2)
-        mock_server._trigger_event.assert_has_calls([
-            mock.call('message', 'sid', foo, run_async=True),
-            mock.call('disconnect', 'sid', run_async=False)])
+        assert s.connected
+        assert mock_server._trigger_event.call_count == 2
+        mock_server._trigger_event.assert_has_calls(
+            [
+                mock.call('message', 'sid', foo, run_async=True),
+                mock.call('disconnect', 'sid', run_async=False),
+            ]
+        )
         ws.send.assert_called_with('4bar')
 
     def test_send_after_close(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.close(wait=False)
-        self.assertRaises(exceptions.SocketIsClosedError, s.send,
-                          packet.Packet(packet.NOOP))
+        with pytest.raises(exceptions.SocketIsClosedError):
+            s.send(packet.Packet(packet.NOOP))
 
     def test_close_after_close(self):
         mock_server = self._get_mock_server()
         s = socket.Socket(mock_server, 'sid')
         s.close(wait=False)
-        self.assertTrue(s.closed)
-        self.assertEqual(mock_server._trigger_event.call_count, 1)
-        mock_server._trigger_event.assert_called_once_with('disconnect', 'sid',
-                                                           run_async=False)
+        assert s.closed
+        assert mock_server._trigger_event.call_count == 1
+        mock_server._trigger_event.assert_called_once_with(
+            'disconnect', 'sid', run_async=False
+        )
         s.close()
-        self.assertEqual(mock_server._trigger_event.call_count, 1)
+        assert mock_server._trigger_event.call_count == 1
 
     def test_close_and_wait(self):
         mock_server = self._get_mock_server()
@@ -423,4 +506,4 @@ class TestSocket(unittest.TestCase):
         s = socket.Socket(mock_server, 'sid')
         s.queue = mock.MagicMock()
         s.close(wait=False)
-        self.assertEqual(s.queue.join.call_count, 0)
+        assert s.queue.join.call_count == 0
